package File::Spec;
use strict;
use vars qw(@ISA $VERSION);
$VERSION = '0.8';
my%module=(MacOS=>'Mac',MSWin32=>'Win32',os2=>'OS2',VMS=>'VMS');
my$module=$module{$^O}||'Unix';
require"File/Spec/$module.pm";
@ISA=("File::Spec::$module");
1;
__END__

