package lib;
use vars qw(@ORIG_INC);
use Config;
my$archname=$Config{'archname'};
@ORIG_INC=@INC;
sub import{shift;
foreach(reverse@_){next unless defined($_);
if($_ eq ''){require Carp;
Carp::carp("Empty compile time value given to use lib");}if(-e&&!-d _){require Carp;
Carp::carp("Parameter to use lib must be directory, not file");}unshift(@INC,$_);
if(-d"$_/$archname"){unshift(@INC,"$_/$archname")if-d"$_/$archname/auto";
unshift(@INC,"$_/$archname/$]")if-d"$_/$archname/$]/auto";}}}sub unimport{shift;
my$mode=shift if$_[0]=~m/^:[A-Z]+/;
my%names;
foreach(@_){++$names{$_};
++$names{"$_/$archname"}if-d"$_/$archname/auto";}if($mode and$mode eq ':ALL'){@INC=grep{!exists$names{$_}}@INC;}else{@INC=grep{--$names{$_}<0}@INC;}}1;
__END__


