package English;
require Exporter;
@ISA=(Exporter);
local$^W=0;
sub import{my$this=shift;
my@list=@_;
local$Exporter::ExportLevel=1;
Exporter::import($this,grep{s/^\$/*/}@list);}@EXPORT=qw(
  *ARG
  *MATCH
  *PREMATCH
  *POSTMATCH
  *LAST_PAREN_MATCH
  *INPUT_LINE_NUMBER
  *NR
  *INPUT_RECORD_SEPARATOR
  *RS
  *OUTPUT_AUTOFLUSH
  *OUTPUT_FIELD_SEPARATOR
  *OFS
  *OUTPUT_RECORD_SEPARATOR
  *ORS
  *LIST_SEPARATOR
  *SUBSCRIPT_SEPARATOR
  *SUBSEP
  *FORMAT_PAGE_NUMBER
  *FORMAT_LINES_PER_PAGE
  *FORMAT_LINES_LEFT
  *FORMAT_NAME
  *FORMAT_TOP_NAME
  *FORMAT_LINE_BREAK_CHARACTERS
  *FORMAT_FORMFEED
  *CHILD_ERROR
  *OS_ERROR
  *ERRNO
  *EXTENDED_OS_ERROR
  *EVAL_ERROR
  *PROCESS_ID
  *PID
  *REAL_USER_ID
  *UID
  *EFFECTIVE_USER_ID
  *EUID
  *REAL_GROUP_ID
  *GID
  *EFFECTIVE_GROUP_ID
  *EGID
  *PROGRAM_NAME
  *PERL_VERSION
  *ACCUMULATOR
  *DEBUGGING
  *SYSTEM_FD_MAX
  *INPLACE_EDIT
  *PERLDB
  *BASETIME
  *WARNING
  *EXECUTABLE_NAME
  *OSNAME
);
*ARG=*_;
*MATCH=*&;
*PREMATCH=*`;
*POSTMATCH=*';
*LAST_PAREN_MATCH=*+;
*INPUT_LINE_NUMBER=*.;
*NR=*.;
*INPUT_RECORD_SEPARATOR=*/;
*RS=*/;
*OUTPUT_AUTOFLUSH=*|;
*OUTPUT_FIELD_SEPARATOR=*,;
*OFS=*,;
*OUTPUT_RECORD_SEPARATOR=*\;
*ORS=*\;
*LIST_SEPARATOR=*";
*SUBSCRIPT_SEPARATOR=*;;
*SUBSEP=*;;
*FORMAT_PAGE_NUMBER=*%;
*FORMAT_LINES_PER_PAGE=*=;
*FORMAT_LINES_LEFT=*-;
*FORMAT_NAME=*~;
*FORMAT_TOP_NAME=*^;
*FORMAT_LINE_BREAK_CHARACTERS=*:;
*FORMAT_FORMFEED=*^L;
*CHILD_ERROR=*?;
*OS_ERROR=*!;
*ERRNO=*!;
*EXTENDED_OS_ERROR=*^E;
*EVAL_ERROR=*@;
*PROCESS_ID=*$;
*PID=*$;
*REAL_USER_ID=*<;
*UID=*<;
*EFFECTIVE_USER_ID=*>;
*EUID=*>;
*REAL_GROUP_ID=*(;
*GID=*(;
*EFFECTIVE_GROUP_ID=*);
*EGID=*);
*PROGRAM_NAME=*0;
*PERL_VERSION=*];
*ACCUMULATOR=*^A;
*COMPILING=*^C;
*DEBUGGING=*^D;
*SYSTEM_FD_MAX=*^F;
*INPLACE_EDIT=*^I;
*PERLDB=*^P;
*BASETIME=*^T;
*WARNING=*^W;
*EXECUTABLE_NAME=*^X;
*OSNAME=*^O;
1;
